@@ -19,7 +19,7 @@ import itertools
 import typing
 from typing import Any, Generic, Iterable, Iterator, Mapping
 
-import cytoolz as toolz
+import toolz
 
 from .aggregation import (
     AggregateSpecification,
@@ -68,6 +68,11 @@ class Relation(abc.ABC):
 
         """
 
+    def __repr__(self) -> str:
+        from stupidb.api import pretty
+
+        return pretty(self)
+
 
 class Table(Relation):
     __slots__ = ("rows",)
@@ -292,7 +297,9 @@ class SortBy(Relation):
                 self.child,
                 key=functools.cmp_to_key(
                     functools.partial(
-                        row_key_compare, self.order_by, self.null_ordering
+                        row_key_compare,
+                        toolz.juxt(*self.order_by),
+                        self.null_ordering,
                     )
                 ),
             )
@@ -302,14 +309,20 @@ class SortBy(Relation):
 class Limit(Relation):
     __slots__ = "child", "offset", "limit"
 
-    def __init__(self, child: Relation, *, offset: int, limit: int) -> None:
+    def __init__(self, child: Relation, *, offset: int, limit: int | None) -> None:
         super().__init__()
         self.child = child
         self.offset = offset
         self.limit = limit
 
     def _produce(self) -> Iterator[AbstractRow]:
-        return itertools.islice(self.child, self.offset, self.offset + self.limit, None)
+        limit = self.limit
+        offset = self.offset
+        return itertools.islice(
+            self.child,
+            offset,
+            None if limit is None else offset + limit,
+        )
 
 
 class Join(Relation):
